@@ -1,7 +1,8 @@
 package Number::Closest::XS;
+use 5.010;
 use strict;
 use warnings;
-our $VERSION = "0.07_03";
+our $VERSION = "0.01";
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -18,7 +19,7 @@ Number::Closest::XS - find numbers closest to a given
 
 =head1 VERSION
 
-This document describes Number::Closest::XS version 0.07_03
+0.01
 
 =head1 SYNOPSIS
 
@@ -28,6 +29,8 @@ This document describes Number::Closest::XS version 0.07_03
 
 =head1 DESCRIPTION
 
+B<Warning:> this is an alpha version. Behaviour is likely to change in the future.
+
 Module provides functions to extract from the list numbers closest to the
 given.
 
@@ -42,14 +45,13 @@ Distance between C<$num> and C<$x> computed as C<abs($num - $x)>.
 
 =head2 find_closest_numbers_around($num, \@list, [$amount])
 
-selects from the I<@list> up to I<$amount> numbers closest to the I<$num>.
-Tries to select equal amounts of numbers from both sides of the I<$num>, but if
-there are not enough numbers from one side will select more numbers from the
-other. If I<$amount> is odd, then the last number will be closest to I<$num>,
-e.g. if $num is 5, @list is 1, 2, 6, 7, and amount is 3 it will return 2, 6,
-and 7, because 7 is closer to 5 than 1.  If I<$amount> is not specified, is
-assumed to be 2. Returns reference to the array containing closest numbers
-sorted by their values.
+selects from the I<@list> up to I<$amount> numbers closest to the I<$num>, but
+first tries to ensure that there are numbers from both sides of the I<$num>, so
+if $num is 5, @list is 2, 6, 7 and amount is 2 it will return 2 and 6, despite
+7 being closer to 5. If I<$amount> is not specified, is assumed to be 2.
+Returns reference to the array containing found numbers sorted by the distance
+from the I<$num>.  Distance between C<$num> and C<$x> computed as
+C<abs($num - $x)>.
 
 =cut
 
@@ -65,10 +67,6 @@ L<Number::Closest>, L<Number::Closest::NonOO>
 
 Pavel Shaydo C<< <zwon at cpan.org> >>
 
-=head1 THANKS
-
-Thanks to Dana Jacobsen for reporting a bug with handling 64 bit integers and long doubles.
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2014 Pavel Shaydo
